piskg (Python IPFS Swarm Key Generator)
=======================================

This program generates swarm.key file for IPFS Private Network feature.

Installing
----------

.. code-block:: bash

      $ pip install piskg


Usage
-----

.. code-block:: bash

      $ piskg > ~/.ipfs/swarm.key


Change `~/.ipfs/` to different directory if you use custom IPFS_PATH.


Credits
-------

Direct port of https://github.com/Kubuxu/go-ipfs-swarm-key-gen/.

License
-------

MIT